#ifndef C_P1CAMERA_COMMON_EVENTS_H
#define C_P1CAMERA_COMMON_EVENTS_H

namespace P1
{
namespace CameraSdk
{
	/**
	* @brief Events for camera related notifications, that are not properties
	*
	*/
	enum CameraEventId
	{
		kCameraEventUndefined = 0,			/**< An undefined event type, intended use is as null event */
		kCameraEventImageTransferBegin,		/**< The camera has started tramsfering an image (0% complete) */
		kCameraEventImageTransferProgress,	/**< A progress update on the current image transfer (+1% or more) */
		kCameraEventImageReady,				/**< An image data ready to be read, as result of previous capture (100% complete) */
		kCameraEventDisconnected,			/**< Camera disconnected and therefore unavailable */
		kCameraEventLiveViewStarted,		/**< LiveView system will begin to feeding images */
		kCameraEventLiveViewStopped,		/**< LiveView system stopped feeding images, and is powered down. */
		kCameraEventNewLiveViewImage,		/**< A new LiveView image has arrived and is ready to be consumed by you */
		kCameraEventPropertyAdded,			/**< A new property became present on the camera */
		kCameraEventPropertyRemoved,		/**< A property was removed from the camera */
	};

	/** @brief Global events that does not relate to specific cameras */
	enum SdkEventId
	{
		kSdkEventUndefined = 0,	/**< A 'not set' value for SdkEvent */
		kSdkEventCameraFound,	/**< A camera was connected to the computer */
		kSdkEventCameraRemoved, /**< A camera was removed from the computer */
		kSdkEventCameraOpened,  /**< A camera was opened by the SDK (on this computer) */
		kSdkEventCameraClosed   /**< A camera was closed by the SDK (on this computer) */
	};

	/** @brief Defines which type of event a notification contains */
	enum NotificationType
	{
		kNotificationTypeUndefined = 0,			/**< Unknown / invalid Notification */
		kNotificationTypeProperty = 1,			/**< Notification describes a property value change event */
		kNotificationTypeCameraEvent = 2,		/**< Notification describes a camera event */
		kNotificationTypeSdkEvent = 3,			/**< Notification describes a global SDK event */
		kNotificationTypeSpecificationChange = 4/**< Notification describes that a PropertySpecification has changed (not its value) */
	};

} // CameraSdk
} // P1

#endif // C_P1CAMERA_COMMON_EVENTS_H
