#ifndef C_P1CAMERA_COMMON_PROPERTIES_H
#define C_P1CAMERA_COMMON_PROPERTIES_H

#include <cstdint>

/**
* @file P1CameraSdkCommonProperties.h
* @brief This *Common* file contains shared code that can be used high-level APIs
*		 The C++ API layer include this file, since it might define shared types and enums.
*/

namespace P1
{
namespace CameraSdk
{
	enum TetherConnection
	{
		kTetherConnection_Undefined,
		kTetherConnection_USB,
		kTetherConnection_USB_2,
		kTetherConnection_USB_3,
		kTetherConnection_TCPIP
	};

	/**
	 * @brief Properties a can have different types, like integers, strings or rectangles.
	 *		  This enum define available types.
	 */
	enum PropertyType
	{
		kPropertyTypeUndefined = 0,

		kPropertyTypeBool = 1,
		kPropertyTypeInt32 = 2,
		kPropertyTypeUInt32 = 3,
		kPropertyTypeInt64 = 4,
		kPropertyTypeUInt64 = 5,
		kPropertyTypeFloat64 = 6,
		kPropertyTypeString = 7,
		kPropertyTypeEnum = 8,

		kPropertyTypePoint = 9,   // Point<S32>
		// kPropertyTypePointFloat = 10,   // Point<F64> Not supported, yet
		kPropertyTypeArea = 11,   // Area<S32>
		kPropertyTypeAreaFloat = 12, // Area<F64>
		kPropertyTypeRect = 13,   // Rect<S32>
		// kPropertyTypeRectFloat = 14,   // Rect<F64> Not supported, yet

		//kPropertyTypeColorRGB = 15,   // ColorRGB<U32> Not supported, yet
		kPropertyTypeColorRGBFloat = 16,   // ColorRGB<F64>
		//kPropertyTypeColorARGB = 17,   // ColorARGB<U32> Not supported, yet
		kPropertyTypeColorARGBFloat = 18,   // ColorARGB<F64>

		kPropertyTypeRange = 19,   // Range<S32>/Range<U32>
		kPropertyTypeRangeFloat = 20,   // Range<F64>

		kPropertyTypeTime = 21			// kValueType_Time64
	};

	enum PropertyUserLevel
	{
		kPropertyUserLevelUndefined = 0,
		kPropertyUserLevelBasic = 5,
		kPropertyUserLevelAdvanced = 10,
		kPropertyUserLevelDeveloper = 20,
	};

	enum PropertyConstants
	{
		// Property values for properties of type PropertyType.String cannot exceed 255 bytes.
		// That's a limitation in the communication API with the camera. If a property is tried
		// set with a string exceeding this, an error is reported and the property is not updated.
		kPropertyTypeStringMaxLength = 255
	};

	const uint32_t kPropertyUndefined = 0xFFFFFFFF;

} // CameraSdk
} // P1

#endif // C_P1CAMERA_COMMON_PROPERTIES_H